# Counterpartner
A short code for creating matched pairs from groups.

Visit the active code via :
https://github.com/richardtjornhammar/counterpartner

Visit the published code : 
https://zenodo.org/record/3833963

Cite using :
DOI: 10.5281/zenodo.3833963

Install with :
pip install counterpartner
